# Jerry
***Meet Oliver, your video alchemist. Drop him an M3U8 link, and he'll whip up a lightning-fast concoction, delivering a sleek MP4 straight to your local realm. Oliver's all about that need-for-speed vibe!***

**make sure you have [ffmpeg](https://ffmpeg.org/download.html) installed**


**Install poetry**
```bash
pip install poetry
```

**Install dependancies**
```bash
poetry install
```

**Create and run virtual environment**
```bash
poetry shell
```

**run**
```bash
python oliver.py
```